/*
 * DomUI Java User Interface library
 * Copyright (c) 2010 by Frits Jalvingh, Itris B.V.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * See the "sponsors" file for a list of supporters.
 *
 * The latest version of DomUI and related code, support and documentation
 * can be found at http://www.domui.org/
 * The contact for the project is Frits Jalvingh <jal@etc.to>.
 */
package to.etc.domui.converter;

import java.util.*;

import to.etc.domui.component.meta.*;
import to.etc.domui.trouble.*;
import to.etc.domui.util.*;

/**
 * Converts a Double value to a string and v.v., the double is treated as a
 * real number.
 * FIXME This does not properly do locale handling!!!!!
 *
 * @author <a href="mailto:jal@etc.to">Frits Jalvingh</a>
 * Created on Dec 10, 2010
 */
public class DoubleConverter implements IConverter<Double> {
	private int m_scale = -1;

	private NumericPresentation m_pre;

	public DoubleConverter() {}

	public DoubleConverter(PropertyMetaModel< ? > pmm) {
		m_scale = pmm.getScale();
		m_pre = pmm.getNumericPresentation();
	}

	public DoubleConverter(NumericPresentation np, int scale) {
		m_scale = scale;
		m_pre = np;
	}

	@Override
	public String convertObjectToString(Locale loc, Double in) throws UIException {
		if(in == null)
			return "";
		if(m_pre == null)
			return String.format(loc, "%.3g", in);
		return NumericUtil.renderNumber(in, m_pre, m_scale);
	}

	@Override
	public Double convertStringToObject(Locale loc, String input) throws UIException {
		if(input == null)
			return null;
		input = input.trim();
		if(input.length() == 0)
			return null;
		try {
			return Double.valueOf(input); // FIXME BAD LOCALE HANDLING
		} catch(Exception x) {
			throw new ValidationException(Msgs.V_INVALID_DOUBLE);
		}
	}
}
